<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! class_exists( 'Afiliatti_Lsc' ) ) :

	/**
	 * Main Afiliatti_Lsc Class.
	 *
	 * @package		ALSC
	 * @subpackage	Classes/Afiliatti_Lsc
	 * @since		1.0.0
	 * @author		Afiliatti
	 */
	final class Afiliatti_Lsc {

		/**
		 * The real instance
		 *
		 * @access	private
		 * @since	1.0.0
		 * @var		object|Afiliatti_Lsc
		 */
		private static $instance;

		/**
		 * ALSC settings object.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @var		object|Afiliatti_Lsc_Settings
		 */
		public $settings;

		/**
		 * Throw error on object clone.
		 *
		 * Cloning instances of the class is forbidden.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @return	void
		 */
		public function __clone() {
			_doing_it_wrong( __FUNCTION__, __( 'You are not allowed to clone this class.', 'afiliatti-lsc' ), '1.0.0' );
		}

		/**
		 * Disable unserializing of the class.
		 *
		 * @access	public
		 * @since	1.0.0
		 * @return	void
		 */
		public function __wakeup() {
			_doing_it_wrong( __FUNCTION__, __( 'You are not allowed to unserialize this class.', 'afiliatti-lsc' ), '1.0.0' );
		}

		/**
		 * Main Afiliatti_Lsc Instance.
		 *
		 * Insures that only one instance of Afiliatti_Lsc exists in memory at any one
		 * time. Also prevents needing to define globals all over the place.
		 *
		 * @access		public
		 * @since		1.0.0
		 * @static
		 * @return		object|Afiliatti_Lsc	The one true Afiliatti_Lsc
		 */
		public static function instance() {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Afiliatti_Lsc ) ) {
				self::$instance					= new Afiliatti_Lsc;
				self::$instance->base_hooks();
				self::$instance->includes();
				self::$instance->settings		= new Afiliatti_Lsc_Settings();

				//Fire the plugin logic
				new Afiliatti_Lsc_Run();

				/**
				 * Fire a custom action to allow dependencies
				 * after the successful plugin setup
				 */
				do_action( 'ALSC/plugin_loaded' );
			}

			return self::$instance;
		}

		/**
		 * Include required files.
		 *
		 * @access  private
		 * @since   1.0.0
		 * @return  void
		 */
		private function includes() {
			require_once ALSC_PLUGIN_DIR . 'core/includes/classes/class-afiliatti-lsc-settings.php';
			require_once ALSC_PLUGIN_DIR . 'core/includes/classes/class-afiliatti-lsc-run.php';
		}

		/**
		 * Add base hooks for the core functionality
		 *
		 * @access  private
		 * @since   1.0.0
		 * @return  void
		 */
		private function base_hooks() {
			add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );
		}

		/**
		 * Loads the plugin language files.
		 *
		 * @access  public
		 * @since   1.0.0
		 * @return  void
		 */
		public function load_textdomain() {
			load_plugin_textdomain( 'afiliatti-lsc', FALSE, dirname( plugin_basename( ALSC_PLUGIN_FILE ) ) . '/languages/' );
		}

	}

endif; // End if class_exists check.