<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Class Afiliatti_Lsc_Run
 *
 * Thats where we bring the plugin to life
 *
 * @package		ALSC
 * @subpackage	Classes/Afiliatti_Lsc_Run
 * @author		Afiliatti
 * @since		1.0.0
 */
class Afiliatti_Lsc_Run{

	/**
	 * Our Afiliatti_Lsc_Run constructor 
	 * to run the plugin logic.
	 *
	 * @since 1.0.0
	 */
	function __construct(){
		$this->add_hooks();
	}

	/**
	 * ######################
	 * ###
	 * #### WORDPRESS HOOKS
	 * ###
	 * ######################
	 */

	/**
	 * Registers all WordPress and plugin related hooks
	 *
	 * @access	private
	 * @since	1.0.0
	 * @return	void
	 */
	private function add_hooks(){
	
		add_action( 'plugin_action_links_' . ALSC_PLUGIN_BASE, array( $this, 'add_plugin_action_link' ), 20 );
        add_action( 'admin_print_styles-edit.php', array( $this, 'alsc_stats_load_admin_css'));
        add_filter( 'manage_posts_columns', array( $this, 'alsc_stats_post_table'));
        add_action( 'manage_posts_custom_column',  array( $this, 'alsc_post_table_cell') , 10, 2 );
        add_action( 'admin_menu', array( $this, 'alsc_settings_link') );
        add_action( 'admin_init', array( $this, 'alsc_build_fields' ));

    }

	/**
	 * ######################
	 * ###
	 * #### WORDPRESS HOOK CALLBACKS
	 * ###
	 * ######################
	 */

	/**
	* Adds action links to the plugin list table
	*
	* @access	public
	* @since	1.0.0
	*
	* @param	array	$links An array of plugin action links.
	*
	* @return	array	An array of plugin action links.
	*/

	public function add_plugin_action_link( $links ) {
		$links['config'] = sprintf( '<a href="%s" title="Custom Link" style="font-weight:700;">%s</a>', '/wp-admin/options-general.php?page=afiliatti-lsc-settings', __( 'Configuration', 'afiliatti-lsc' ) );
		return $links;
	}

    function alsc_stats_load_admin_css() {
        ?>
        <style type="text/css">
            .fixed .alsc-stats {
                text-align:center;
            }

            #alsc-stats {
                text-align:center;
            }
        </style>
        <?php
    }

    function alsc_stats_post_table( $columns ) {
        $columns['alsc-stats'] = esc_html__( 'Search Console', 'afiliatti-lsc' );
        return $columns;
    }

    function alsc_post_table_cell( $column, $post_id ) {
        if ( 'alsc-stats' === $column ) {

                if(get_option('alsc_resource') == "") {
                    echo'-';
                }
                else {
                    $post_url = urlencode(get_permalink($post_id));
                    $stats_post_url = 'https://search.google.com/search-console/performance/search-analytics?resource_id='.get_option('alsc_resource').'&hl=en&breakdown=query&page=!'.$post_url.'&metrics=CLICKS%2CIMPRESSIONS%2CCTR%2CPOSITION';
                    printf(
                        '<a href="%s" title="%s" class="dashicons dashicons-google" target="_blank"></a>',
                        esc_url( $stats_post_url ),
                        esc_html__( 'View stats for this post in Google Search Console', 'afiliatti-lsc' )
                    );
                }
        }
    }

    function alsc_settings_link() {
        add_options_page( 'Afiliatti LSC', 'Afiliatti LSC', 'manage_options', 'afiliatti-lsc-settings', array( $this, 'alsc_settings_page') );
    }

    function alsc_settings_page() {
        echo'
        <div class="wrap">
            <h2>Afiliatti Link Search Console</h2>
            <p>Because Google Search Console use different type of URLs for reports (based on how the domain is verified), you have to check your domain and enter below the <b>?resource_id</b> parameter.<br/>
             Just go to Google Search Console -> Select website from the left and then take a look into the address bar.</p>
             
             <p>There\'s just 3 options available:
             <ul>
                 <li>https://search.google.com/search-console?resource_id=<b style="color:red;">sc-domain%3Adomain.com</b>&hl=en</li>
                 <li>https://search.google.com/search-console?resource_id=<b style="color:red;">https%3A%2F%2Fwww.domain.com%2F</b>&hl=en</li>
                 <li>https://search.google.com/search-console?resource_id=<b style="color:red;">https%3A%2F%2Fdomain.com%2F</b>&hl=en</li>
             </ul>
             </p>
             
             <p>Copy&Paste into the field below the <b>resource_id</b> parameter from your URL.

            <form method="POST" action="options.php">';
        settings_fields( 'alsc_settings' );
        do_settings_sections( 'alsc_settings' );
        submit_button();
        echo'</form> 
        </div>';
    }

    public function alsc_build_fields() {
        /**
         * First, we add_settings_section. This is necessary since all future settings must belong to one.
         * Second, add_settings_field
         * Third, register_setting
         */
        add_settings_section(
            'alsc_section',
            '',
            '',
            'alsc_settings'
        );
        unset($args);
        $args = array (
            'type'      => 'input',
            'subtype'   => 'text',
            'id'    => 'alsc_resource',
            'name'      => 'alsc_resource',
            'required' => 'true',
            'get_options_list' => '',
            'value_type'=>'normal',
            'wp_data' => 'option'
        );
        add_settings_field(
            'alsc_resource',
            'Resource ID:',
            array( $this, 'render_settings_field' ),
            'alsc_settings',
            'alsc_section',
            $args
        );


        register_setting(
            'alsc_settings',
            'alsc_resource'
        );

    }

    public function render_settings_field($args) {
        if($args['wp_data'] == 'option'){
            $wp_data_value = get_option($args['name']);
        } elseif($args['wp_data'] == 'post_meta'){
            $wp_data_value = get_post_meta($args['post_id'], $args['name'], true );
        }

        switch ($args['type']) {

            case 'input':
                $value = ($args['value_type'] == 'serialized') ? serialize($wp_data_value) : $wp_data_value;
                if($args['subtype'] != 'checkbox'){
                    $prependStart = (isset($args['prepend_value'])) ? '<div class="input-prepend"> <span class="add-on">'.$args['prepend_value'].'</span>' : '';
                    $prependEnd = (isset($args['prepend_value'])) ? '</div>' : '';
                    $step = (isset($args['step'])) ? 'step="'.$args['step'].'"' : '';
                    $min = (isset($args['min'])) ? 'min="'.$args['min'].'"' : '';
                    $max = (isset($args['max'])) ? 'max="'.$args['max'].'"' : '';
                    if(isset($args['disabled'])){
                        // hide the actual input bc if it was just a disabled input the info saved in the database would be wrong - bc it would pass empty values and wipe the actual information
                        echo $prependStart.'<input type="'.$args['subtype'].'" id="'.$args['id'].'_disabled" '.$step.' '.$max.' '.$min.' name="'.$args['name'].'_disabled" size="40" disabled value="' . esc_attr($value) . '" /><input type="hidden" id="'.$args['id'].'" '.$step.' '.$max.' '.$min.' name="'.$args['name'].'" size="40" value="' . esc_attr($value) . '" />'.$prependEnd;
                    } else {
                        echo $prependStart.'<input type="'.$args['subtype'].'" id="'.$args['id'].'" "'.$args['required'].'" '.$step.' '.$max.' '.$min.' name="'.$args['name'].'" size="40" value="' . esc_attr($value) . '" />'.$prependEnd;
                    }

                } else {
                    $checked = ($value) ? 'checked' : '';
                    echo '<input type="'.$args['subtype'].'" id="'.$args['id'].'" "'.$args['required'].'" name="'.$args['name'].'" size="40" value="1" '.$checked.' />';
                }
                break;
            default:
                # code...
                break;
        }
    }
}